#ifndef INCLUDED_PYECASOUND_H
#define INCLUDED_PYECASOUND_H

#ifdef __cplusplus
extern "C" {
#endif

void initpyecasound(void);

#ifdef __cplusplus
}
#endif

#endif
